# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"func": "batch_process_segmentation.ipynb",
         "process_experiment_command": "batch_process_segmentation.ipynb",
         "process_experiment": "batch_process_segmentation.ipynb",
         "nlm_denoise": "denoise_images.ipynb",
         "doLap": "focus_stacking.ipynb",
         "focus_stack": "focus_stacking.ipynb",
         "require_jvm": "load_bioformats_images.ipynb",
         "get_image_reader": "load_bioformats_images.ipynb",
         "kill_jvm": "load_bioformats_images.ipynb",
         "load_slice": "load_tiff_images.ipynb",
         "load_meta": "load_bioformats_images.ipynb",
         "load_image": "load_tiff_images.ipynb",
         "load_hough_segmentation": "process_segmentation.ipynb",
         "compute_overlap": "process_segmentation.ipynb",
         "make_overlap_graph": "process_segmentation.ipynb",
         "plot_circles_on_img": "process_segmentation.ipynb",
         "lt_mean_filter": "process_segmentation.ipynb",
         "create_circular_mask": "process_segmentation.ipynb",
         "compute_patch_coordinates": "process_segmentation.ipynb",
         "extract_patch_from_image": "process_segmentation.ipynb",
         "extract_patches_from_image": "process_segmentation.ipynb",
         "find_hough_circle_per_node": "process_segmentation.ipynb",
         "hough_filter": "process_segmentation.ipynb",
         "erronous_segmentations_filter": "process_segmentation.ipynb"}

modules = ["analyse_intensity.py",
           "batch_process_segmentation.py",
           "denoise.py",
           "focus_stacking.py",
           "load_bioformats_images.py",
           "load_tiff_images.py",
           "process_segmentation.py"]

doc_url = "https://mlippeve.github.io/c7m/"

git_url = "https://github.com/mlippeve/c7m/tree/master/"

def custom_doc_links(name): return None
